==> cell_tracking_bc-2022.30-py3-none-any.whl: cell_tracking_BC/type/acquisition/frame.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from io import BytesIO as io_bytes_t
from typing import Dict, Sequence, Tuple

import numpy as nmpy


array_t = nmpy.ndarray
all_versions_h = Dict[
    str, Tuple[Tuple[int, int], Sequence[array_t]]
]


def AsCompressedArray(frame: array_t, /) -> io_bytes_t:
    """"""
    output = io_bytes_t()
    nmpy.savez_compressed(output, array=frame)

    return output

==> cell_tracking_bc-2023.2-py3-none-any.whl: cell_tracking_BC/type/acquisition/frame.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from io import BytesIO as frame_t

import numpy as nmpy


array_t = nmpy.ndarray


def NewFromArray(array: array_t, /) -> frame_t:
    """"""
    output = frame_t()

    # The "array" keyword is used in "AsUncompressedArray"
    nmpy.savez_compressed(output, array=array)

    return output


def AsUncompressedArray(frame: frame_t, /) -> array_t:
    """"""
    frame.seek(0)

    # The "array" keyword is used here
    return nmpy.load(frame)["array"]
